// https://nuxt.com/docs/api/configuration/nuxt-config
export default defineNuxtConfig({
  devtools: { enabled: true },

  css: [
    'assets/css/theme.css',
    'assets/css/common.css',
    'assets/css/header.css',
    'assets/css/footer.css',
    'assets/css/pages/home.css',
    'assets/css/pages/projects.css',
    'assets/css/pages/about.css',
    'assets/css/pages/cv.css'
  ],

  app: {
    head: {
      title: 'Portfolio',
      meta: [
        { charset: 'utf-8' },
        { name: 'viewport', content: 'width=device-width, initial-scale=1' },
        { name: 'description', content: 'Portfolio professionnel' }
      ],
      link: [
        {
          rel: 'icon',
          type: 'image/x-icon',
          href: '/favicon.ico'
        }
      ],
    },
    buildAssetsDir: '/containers/matheothierry-portfolio_nuxt/_nuxt/',
  },

  modules: ['@nuxt/image'],

  plugins: [
    { src: '~/plugins/router.ts', mode: 'client' },
    { src: '~/plugins/theme.ts', mode: 'client' }
  ],

  image: {
    provider: 'ipx',
    ssr: false,
    quality: 80,
    format: ['webp', 'jpg', 'png', 'jpeg'],
    screens: {
      xs: 320,
      sm: 640,
      md: 768,
      lg: 1024,
      xl: 1280,
      xxl: 1536,
    },
    dir: 'public',
    domains: [],
    alias: {},
    ipx: {
      maxAge: 60 * 60 * 24 * 30
    },
  },
})
